#!/bin/bash

# this script searches for a specified java version and runs an application
# copyleft Krzysztof Sadlocha

found_java=''
found_ver=''
min_ver='1.4'

this_path=`expr match "$0" '\(.*\)/[^/]*'`



if [ "$JAVA_HOME" == "" ]
then
   if [ -f "$this_path/set_java_home.sh" ]
   then
      source "$this_path/set_java_home.sh"
      if [ -d "$JAVA_HOME" ]
      then
      :
      else
         JAVA_HOME=""
      fi
   fi
fi

if [ "$JAVA_HOME" != "" ]
then
   if [ -d "$JAVA_HOME" ]
   then
      echo using JAVA_HOME $JAVA_HOME
      found_java="$JAVA_HOME"
   fi
fi


if [ "$found_java" == "" ]
then
   
   jdk_pattern='\(.*j.*dk1\.[^/]*\)/bin/java'
   jre_pattern='\(.*jre1\.[^/]*\)/bin/java'
   jdk_ver_pat='.*j.*dk\(1\.[^/]*\)/bin/java'
   jre_ver_pat='.*jre\(1\.[^/]*\)/bin/java'

   bb=`which java`
   if [ "${bb:0:1}" == "/" ]
   then
      bb=`which readlink`
      if [ "${bb:0:1}" == "/" ]
      then
         echo looking for default java

         def_java=`which java`
         def_java=`readlink -f -n "$def_java"`

         found_ver=`expr match "$def_java" "$jdk_ver_pat"`
         if [ "$found_ver" != "" ]
         then
            found_java=`expr match "$def_java" "$jdk_pattern"`
         else
            found_ver=`expr match "$def_java" "$jre_ver_pat"`
            if [ "$found_ver" != "" ]
            then
               found_java=`expr match "$def_java" "$jre_pattern"`
            fi
         fi

         if [ "$found_java" != "" ]
         then
            echo default java is $found_java version $found_ver
         else
            echo default java $def_java unrecognized vendor
         fi
      else
         echo no default java
      fi
   fi

   if expr "$found_ver" \< "$min_ver" &> /dev/null 
   then

      for fdir in '/usr/java' '/usr' '/'
      do
         echo looking for JDKs in $fdir
         for fjava in $( find $fdir -xdev -type f -name 'java' )
         do

            #first JDK than JRE
            fver=`expr match "$fjava" "$jdk_ver_pat"`
            if [ "$fver" != "" ]
            then
               if expr "$fver" \>= "$found_ver" &> /dev/null 
               then
                  found_ver=$fver
                  found_java=`expr match "$fjava" "$jdk_pattern"`
               fi
            else
               fver=`expr match "$fjava" "$jre_ver_pat"`
               if [ "$fver" != "" ]
               then
                  if expr "$fver" \> "$found_ver" &> /dev/null 
                  then
                     found_ver=$fver
                     found_java=`expr match "$fjava" "$jre_pattern"`
                  fi
               fi
            fi

            echo "checking java $fjava version $fver"
         
         done
 
         if expr "$found_ver" \>= "$min_ver" &> /dev/null 
         then
            break 
         fi

      done
   fi


   if expr "$found_ver" \>= "$min_ver" &> /dev/null 
   then
      echo "found java $found_java version $found_ver"
      echo "#!/bin/bash" > "$this_path/set_java_home.sh"
      echo "JAVA_HOME=\"$found_java\"" >> "$this_path/set_java_home.sh"
   else
      echo "can't find min. java $min_ver"
      exit -1
   fi
fi


cd "$this_path"

"$found_java/bin/java" -jar javuserver.jar $@


